use TEST instead of TESTS

Change-Id: Iee02b6fa4f8f94b957c4dcd845882fa5ba57944e
diff --git a/lab-pipeline.groovy b/lab-pipeline.groovy
index be0688e..250c3a4 100644
--- a/lab-pipeline.groovy
+++ b/lab-pipeline.groovy
@@ -4,7 +4,7 @@
  * Flow parameters:
  *   STACK_TYPE                 Orchestration engine: heat, ''
  *   INSTALL                    What should be installed (k8s, openstack, ...)
  *   TESTS                      What should be tested (k8s, openstack, ...)
  *
  * Expected parameters:
  *
@@ -147,7 +147,7 @@
     // Test
     //
 
-    if (TESTS.toLowerCase().contains('k8s')) {
+    if (TEST.toLowerCase().contains('k8s')) {
         stage('Run k8s bootstrap tests') {
             orchestrate.runConformanceTests(saltMaster, K8S_API_SERVER, 'tomkukral/k8s-scripts')
         }
@@ -4,7 +4,7 @@
  *   STACK_TYPE                 Orchestration engine: heat, ''
  *   INSTALL                    What should be installed (k8s, openstack, ...)
- *   TESTS                      What should be tested (k8s, openstack, ...)
+ *   TEST                       What should be tested (k8s, openstack, ...)
  *
  * Expected parameters: